@@ -24,6 +24,8 @@
 using namespace PGSTD;
 using namespace pqxx::internal::pq;
 
+// TODO: Existing structure doesn't call SetupState()!
+
 pqxx::connection::connection() :
   connection_base(0)
 {
@@ -171,3 +173,7 @@ void pqxx::asyncconnection::completeconnect()
 }
 
 
+pqxx::nullconnection::~nullconnection() throw ()
+{
+}
+
