@@ -375,7 +375,7 @@ void pqxx::connection_base::RemoveTrigger(pqxx::trigger *T) throw ()
     else
     {
       if (m_Conn && (R.second == ++R.first))
-	PQexec(m_Conn, ("UNLISTEN \"" + T->name() + "\"").c_str());
+	Exec(("UNLISTEN \"" + T->name() + "\"").c_str(), 0);
 
       m_Triggers.erase(i);
     }
@@ -438,7 +438,7 @@ int pqxx::connection_base::get_notifs()
 }
 
 
-const char *pqxx::connection_base::ErrMsg() const
+const char *pqxx::connection_base::ErrMsg() const throw ()
 {
   return m_Conn ? PQerrorMessage(m_Conn) : "No connection to database";
 }
@@ -474,6 +474,7 @@ pqxx::result pqxx::connection_base::exec_prepared(const char QueryName[],
 	const char *const *Params,
 	int Retries)
 {
+#ifdef PQXX_HAVE_PQEXECPREPARED
   activate();
   result R(PQexecPrepared(m_Conn, QueryName, NumParams, Params, NULL, NULL, 0));
 
@@ -493,6 +494,14 @@ pqxx::result pqxx::connection_base::exec_prepared(const char QueryName[],
   R.CheckStatus(QueryName);
   get_notifs();
   return R;
+#else
+  stringstream Q;
+  Q << "EXECUTE " 
+    << QueryName
+    << ' '
+    << separated_list(",", Params, Params+NumParams);
+  return Exec(Q.str().c_str(), Retries);
+#endif
 }
 
 
@@ -528,15 +537,7 @@ void pqxx::connection_base::close() throw ()
 
     if (!m_Triggers.empty())
     {
-      string T;
-      for (TriggerList::const_iterator i = m_Triggers.begin(); 
-	   i != m_Triggers.end();
-	   ++i)
-	T += " " + i->first;
-
-        process_notice("Closing connection with outstanding triggers:" + 
-	               T + 
-		       "\n");
+      process_notice("Closing connection with outstanding triggers");
       m_Triggers.clear();
     }
 
@@ -564,8 +565,11 @@ void pqxx::connection_base::AddVariables(const map<string,string> &Vars)
 
 void pqxx::connection_base::InternalSetTrace() throw ()
 {
-  if (m_Trace) PQtrace(m_Conn, m_Trace);
-  else PQuntrace(m_Conn);
+  if (m_Conn)
+  {
+    if (m_Trace) PQtrace(m_Conn, m_Trace);
+    else PQuntrace(m_Conn);
+  }
 }
 
 
@@ -750,7 +754,7 @@ void pqxx::connection_base::start_exec(const string &Q)
 }
 
 
-PGresult *pqxx::connection_base::get_result()
+pqxx::internal::pq::PGresult *pqxx::connection_base::get_result()
 {
   if (!m_Conn) throw broken_connection();
   return PQgetResult(m_Conn);
@@ -772,6 +776,7 @@ namespace
 
 int pqxx::connection_base::set_fdmask() const
 {
+  if (!m_Conn) throw broken_connection();
   const int fd = PQsocket(m_Conn);
   if (fd < 0) throw broken_connection();
   FD_SET(fd, &m_fdmask);
